//
//  PokktMoPubRewardedVideo.m
//  AdMobWrapper
//
//  Created by Pokkt on 24/04/17.
//  Copyright © 2017 Pokkt. All rights reserved.
//

#import "PokktMoPubRewardedVideo.h"

@interface PokktMoPubRewardedVideo () {
    
    NSString *pokktScreenName;
    NSString *appId;
    NSString *securityKey;
}

@end
@implementation PokktMoPubRewardedVideo
@synthesize delegate;

- (void)requestRewardedVideoWithCustomEventInfo:(NSDictionary *)info
{
    NSLog(@"%@",info);
    pokktScreenName = [info objectForKey:@"POKKT_SCREEN_NAME"];
    appId = [info objectForKey:@"POKKT_APP_ID"];
    securityKey = [info objectForKey:@"POKKT_SEC_KEY"];
    BOOL isDebug = [[info objectForKey:@"POKKT_DEBUG"] boolValue];
    NSString *thirdPartyId = [info objectForKey:@"POKKT_THIRD_PARTY_USERID"];
    
    /**
     * In [PokktAds setPokktConfigWithAppId: securityKey:]
     * Replace "AppID" and "SecurityKey"  with the one assigned to you by Pokkt.
     *
     */
    
    [PokktAds setPokktConfigWithAppId:appId securityKey:securityKey];
    
    // optional, set it to true if you want to enable logs for PokktSDK
    
    [PokktDebugger setDebug:isDebug];
    
    [PokktAds setThirdPartyUserId:thirdPartyId];
    [PokktVideoAds setPokktVideoAdsDelegate:self];
    
    [PokktVideoAds cacheRewarded:pokktScreenName];

}

- (void)presentRewardedVideoFromViewController:(UIViewController *)viewController
{
    [PokktVideoAds showRewarded:pokktScreenName withViewController:viewController];
}

#pragma mark Pokkt Video Ads Delegates

- (void)videoAdCachingCompleted: (NSString *)screenName isRewarded: (BOOL)isRewarded reward: (float)reward
{
    [self.delegate rewardedVideoDidLoadAdForCustomEvent:self];
}

- (void)videoAdCachingFailed: (NSString *)screenName isRewarded: (BOOL)isRewarded errorMessage: (NSString *)errorMessage
{
    NSError *err = [NSError errorWithDomain:@"Error"
                                       code:0
                                   userInfo:@{
                                              NSLocalizedDescriptionKey:errorMessage
                                              }];

    [self.delegate rewardedVideoDidFailToLoadAdForCustomEvent:self error:err];
}

- (void)videoAdDisplayed: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    [self.delegate rewardedVideoWillAppearForCustomEvent:self];
}

- (void)videoAdClosed:(NSString *)screenName isRewarded: (BOOL)isRewarded
{
    [self.delegate rewardedVideoDidDisappearForCustomEvent:self];
    
    
}

- (void)videoAdAvailabilityStatus: (NSString *)screenName isRewarded: (BOOL)isRewarded isAdAvailable: (BOOL)isAdAvailable
{
}

- (void)videoAdFailedToShow: (NSString *)screenName isRewarded: (BOOL)isRewarded errorMessage: (NSString *)errorMessage
{
    NSError *err = [NSError errorWithDomain:@"Error"
                                       code:0
                                   userInfo:@{
                                              NSLocalizedDescriptionKey:errorMessage
                                              }];
    [self.delegate rewardedVideoDidFailToPlayForCustomEvent:self error:err];
}

- (void)videoAdGratified: (NSString *)screenName reward:(float)reward
{
    MPRewardedVideoReward *rewardData = [[MPRewardedVideoReward alloc] initWithCurrencyAmount:[NSNumber numberWithFloat:reward]];
    [self.delegate rewardedVideoShouldRewardUserForCustomEvent:self reward:rewardData];
}

- (void)videoAdCompleted: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    [self.delegate rewardedVideoWillDisappearForCustomEvent:self];
}

- (void)videoAdSkipped: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
   [self.delegate rewardedVideoDidDisappearForCustomEvent:self];  
}


@end
